Index: /branches/pap_branch_070920/psLib/src/fits/psFits.h
===================================================================
--- /branches/pap_branch_070920/psLib/src/fits/psFits.h	(revision 15176)
+++ /branches/pap_branch_070920/psLib/src/fits/psFits.h	(revision 15177)
@@ -4,6 +4,6 @@
  * @author Robert DeSonia, MHPCC
  *
- * @version $Revision: 1.31.2.4 $ $Name: not supported by cvs2svn $
- * @date $Date: 2007-10-03 20:21:45 $
+ * @version $Revision: 1.31.2.5 $ $Name: not supported by cvs2svn $
+ * @date $Date: 2007-10-03 20:57:13 $
  * Copyright 2004-2005 Maui High Performance Computing Center, University of Hawaii
  */
@@ -55,5 +55,7 @@
     bool writable;                      ///< Is the file writable?
     char *extword;                      ///< user-specified word to name extensions (NULL implies EXTNAME)
-    bool compConvention;                ///< Honour compression convention, handling compressed images
+    struct {
+        bool compression;               ///< Honour compression convention, handling compressed images
+    } conventions;                      ///< Conventions to honour
 } psFits;
 
Index: /branches/pap_branch_070920/psLib/src/fits/psFitsHeader.c
===================================================================
--- /branches/pap_branch_070920/psLib/src/fits/psFitsHeader.c	(revision 15176)
+++ /branches/pap_branch_070920/psLib/src/fits/psFitsHeader.c	(revision 15177)
@@ -7,6 +7,6 @@
  *  @author Robert DeSonia, MHPCC
  *
- *  @version $Revision: 1.34.4.6 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2007-10-03 20:16:49 $
+ *  @version $Revision: 1.34.4.7 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2007-10-03 20:57:13 $
  *
  *  Copyright 2004-2005 Maui High Performance Computing Center, University of Hawaii
@@ -72,5 +72,5 @@
     PS_ASSERT_FITS_NON_NULL(fits, false);
 
-    if (!fits->compConvention) {
+    if (!fits->conventions.compression) {
         // User has turned off compression conventions; doesn't want any nasty surprises
         return false;
@@ -250,5 +250,5 @@
             } else if (strcasecmp(keyValueFixed, "-INF") == 0) {
                 success = psMetadataAddF32(header, PS_LIST_TAIL, keyName, dupFlag, keyComment, -INFINITY);
-            } else if (!fits->compConvention ||
+            } else if (!fits->conventions.compression ||
                        (strcmp(keyName, "EXTNAME") != 0 || strcmp(keyValueFixed, "COMPRESSED_IMAGE") != 0)) {
                 // Ignore EXTNAME=COMPRESSED_IMAGE if compression convention is to be respected

Index: /branches/pap_branch_070920/psLib/src/fits/psFits.c
===================================================================
--- /branches/pap_branch_070920/psLib/src/fits/psFits.c	(revision 15176)
+++ /branches/pap_branch_070920/psLib/src/fits/psFits.c	(revision 15177)
@@ -7,6 +7,6 @@
  *  @author Robert DeSonia, MHPCC
  *
- *  @version $Revision: 1.71.2.4 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2007-10-03 20:21:45 $
+ *  @version $Revision: 1.71.2.5 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2007-10-03 20:57:13 $
  *
  *  Copyright 2004-2005 Maui High Performance Computing Center, University of Hawaii
@@ -162,5 +162,5 @@
     fits->writable = (iomode == READWRITE);
     fits->extword = NULL;
-    fits->compConvention = true;
+    fits->conventions.compression = true;
     psMemSetDeallocator(fits,(psFreeFunc)fitsFree);
 
@@ -238,5 +238,5 @@
 // really want to be able to read these files (MegaCam data are shipped as imcopy-compressed images).
 // Therefore, we implement our own version of moving to an extension specified by name.  The pure cfitsio
 // version is used if "compConvention" handling is turned off in the psFits structure.
 bool psFitsMoveExtName(const psFits* fits,
                        const char* extname)
@@ -247,5 +247,5 @@
     int status = 0;
 
-    if (!fits->compConvention && !fits->extword) {
+    if (!fits->conventions.compression && !fits->extword) {
         // User wants to use cfitsio.  Good luck to them!
         if (fits_movnam_hdu(fits->fd, ANY_HDU, (char*)extname, 0, &status) != 0) {
@@ -256,5 +256,5 @@
     }
 
-    bool ignoreCI = (fits->compConvention &&
+    bool ignoreCI = (fits->conventions.compression &&
                      (strcmp(extname, "COMPRESSED_IMAGE") != 0)); // Ignore COMPRESSED_IMAGE extension name?
     char *extword = (fits->extword ? fits->extword : "EXTNAME"); // Word to use as extension name
@@ -238,5 +238,5 @@
 // really want to be able to read these files (MegaCam data are shipped as imcopy-compressed images).
 // Therefore, we implement our own version of moving to an extension specified by name.  The pure cfitsio
-// version is used if "compConvention" handling is turned off in the psFits structure.
+// version is used if "conventions.compression" handling is turned off in the psFits structure.
 bool psFitsMoveExtName(const psFits* fits,
                        const char* extname)